edx-rbac
=============================

|pypi-badge| |travis-badge| |codecov-badge| |doc-badge| |pyversions-badge|
|license-badge|

Overview
--------

Library to help manage role based access controls for django services.

* See the `Getting started <https://github.com/edx/edx-rbac/blob/master/docs/getting_started.rst>`_ guide to setup
  your development environment.

* See the `How To Guide <https://github.com/edx/edx-rbac/blob/master/docs/how_to_guide.rst>`_ to learn about the
  fundamentals of edx-rbac and how to implement RBAC in your Django service.

License
-------

The code in this repository is licensed under the AGPL 3.0 unless
otherwise noted.

Please see ``LICENSE.txt`` for details.

How To Contribute
-----------------

Contributions are very welcome.

Please read `How To Contribute <https://github.com/edx/edx-platform/blob/master/CONTRIBUTING.rst>`_ for details.

Even though they were written with ``edx-platform`` in mind, the guidelines
should be followed for Open edX code in general.

PR description template should be automatically applied if you are sending PR from github interface; otherwise you
can find it it at `PULL_REQUEST_TEMPLATE.md <https://github.com/edx/edx-rbac/blob/master/.github/PULL_REQUEST_TEMPLATE.md>`_

Issue report template should be automatically applied if you are sending it from github UI as well; otherwise you
can find it at `ISSUE_TEMPLATE.md <https://github.com/edx/edx-rbac/blob/master/.github/ISSUE_TEMPLATE.md>`_

Reporting Security Issues
-------------------------

Please do not report security issues in public. Please email security@edx.org.

Getting Help
------------

Have a question about this repository, or about Open edX in general?  Please
refer to this `list of resources`_ if you need any assistance.

.. _list of resources: https://open.edx.org/getting-help


.. |pypi-badge| image:: https://img.shields.io/pypi/v/edx-rbac.svg
    :target: https://pypi.python.org/pypi/edx-rbac/
    :alt: PyPI

.. |travis-badge| image:: https://travis-ci.org/edx/edx-rbac.svg?branch=master
    :target: https://travis-ci.org/edx/edx-rbac
    :alt: Travis

.. |codecov-badge| image:: http://codecov.io/github/edx/edx-rbac/coverage.svg?branch=master
    :target: http://codecov.io/github/edx/edx-rbac?branch=master
    :alt: Codecov

.. |doc-badge| image:: https://readthedocs.org/projects/edx-rbac/badge/?version=latest
    :target: http://edx-rbac.readthedocs.io/en/latest/
    :alt: Documentation

.. |pyversions-badge| image:: https://img.shields.io/pypi/pyversions/edx-rbac.svg
    :target: https://pypi.python.org/pypi/edx-rbac/
    :alt: Supported Python versions

.. |license-badge| image:: https://img.shields.io/github/license/edx/edx-rbac.svg
    :target: https://github.com/edx/edx-rbac/blob/master/LICENSE.txt
    :alt: License
